@@ -12,10 +12,12 @@
 #    under the License.
 
 from blazarclient import client as blazar_client
-from keystoneauth1.exceptions import http as ks_exc
+from blazarclient import exception as client_exception
 from oslo_config import cfg
 
+from heat.common import exception
 from heat.engine.clients import client_plugin
+from heat.engine import constraints
 
 CLIENT_NAME = 'blazar'
 
@@ -38,7 +40,36 @@ class BlazarClientPlugin(client_plugin.ClientPlugin):
         return client
 
     def is_not_found(self, exc):
-        return isinstance(exc, ks_exc.NotFound)
+        # TODO(asmita): Implement exception NotFound in blazarclient
+        if isinstance(exc, client_exception.BlazarClientException) \
+                and exc.kwargs['code'] == 404:
+            return True
+        return False
 
     def has_host(self):
         return True if self.client().host.list() else False
+
+    def create_lease(self, **args):
+        return self.client().lease.create(**args)
+
+    def get_lease(self, id):
+        return self.client().lease.get(id)
+
+    def create_host(self, **args):
+        return self.client().host.create(**args)
+
+    def get_host(self, id):
+        return self.client().host.get(id)
+
+
+class BlazarBaseConstraint(constraints.BaseCustomConstraint):
+
+    resource_client_name = CLIENT_NAME
+
+
+class ReservationConstraint(BlazarBaseConstraint):
+    expected_exceptions = (
+        exception.EntityNotFound,
+        client_exception.BlazarClientException,)
+
+    resource_getter_name = 'get_lease'
